// CHora.cpp: implementation of the CHora class.
//
//////////////////////////////////////////////////////////////////////

#include "CHora.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CHora::CHora()				//constructor por defecto, todo en cero
{
	t.tm_hour=0;
	t.tm_isdst=-1;
	t.tm_mday=0;
	t.tm_min=0;
	t.tm_mon=0;
	t.tm_sec=0;
	t.tm_wday=0;
	t.tm_yday=0;
	t.tm_year=0;
}

CHora::~CHora()				//destructor (no necesita hacer cosas)
{
}

CHora::CHora(int h, int m, int s)	//constructor usando hh:mm:ss
{
	t.tm_hour=h;
	t.tm_isdst=-1;
	t.tm_mday=0;
	t.tm_min=m;
	t.tm_mon=0;
	t.tm_sec=s;
	t.tm_wday=0;
	t.tm_yday=0;
	t.tm_year=0;
}


int CHora::VHora(void) const		//muestra las horas
{
	return(t.tm_hour);
}
	
int CHora::VMin(void) const			// muestra los minutos
{
	return(t.tm_min);
}

int CHora::VSeg(void) const			// muestra los segundos
{
	return(t.tm_sec);
}

int CHora::MHora(int h)				// cambia las horas
{
	t.tm_hour=h%24;					// y arrasta lo que sobra
	if (h>24) t.tm_mday=t.tm_mday+h%24;
	return(h);
}

int CHora::MMin(int m)				// cambia los minutos
{
	t.tm_min=m%60;					// y arrastra lo que sobra
	if (m>59) MHora(t.tm_hour+m/60);
	return(m);
}

int CHora::MSeg(int s)				// cambia los segundos
{
	t.tm_sec=s%60;					// yarrastra lo que sobra
	if (s>59) MMin(t.tm_min+s/60);
	return(s);
}

long CHora::AHora(void)
{
	struct tm *ta;					// devuelve la hora actual
	time_t tt;						// como un long con el total
	tt=time(NULL);					// de segundos transcurridos
	ta=localtime(&tt);				// en el dia
	return((*ta).tm_hour*3600+(*ta).tm_min*60+(*ta).tm_min);
}

CHora operator+(CHora H1, CHora H2)
{
	CHora H;						// define el operador suma
	H.MHora(H1.VHora() + H2.VHora());
	H.MMin(H1.VMin() + H2.VMin());	// como la suma de cada componente
	H.MSeg(H1.VSeg() + H2.VSeg());	// con el arrastre
	H.t.tm_wday=H1.t.tm_wday+H2.t.tm_wday;
	return (H);
}

CHora operator-(CHora H1, CHora H2)
{
	CHora H;						// define la resta
	long l1,l2, l3;
	l1=(H1.VHora()*3600+H1.VMin()*60+H1.VSeg());
	l2=(H2.VHora()*3600+H2.VMin()*60+H2.VSeg());
	l3=l1-l2;
	while (l3<0)					// y la calcula pasando todo a segundos
	{								// restando y devolviendose despues
		l3=l3+86400;
		H.t.tm_mday--;
	}
	H.MHora(l3/3600);
	H.MMin((l3%1440)/60);
	H.MSeg(l3%60);
	return (H);
}

CHora operator*(int i, CHora H1)
{
	CHora H;						// define la multipicacion por escalar
	H.MHora(i*H1.VHora());			// de forma similar a la suma
	H.MMin(i*H1.VMin());
	H.MSeg(i*H1.VSeg());
	return (H);
}

CHora operator/(CHora H1, int i)
{
	CHora H;						// define la division
	long l;							// de manera similar a la resta
	l=(H1.VHora()*3600+H1.VMin()*60+H1.VSeg())/i;
	H.MHora(l/3600);
	H.MMin((l%1440)/60);
	H.MSeg(l%60);
	return (H);
}